package reset;

import java.io.File;
import java.util.Hashtable;
import java.util.Enumeration;
import javax.swing.*;
import javax.swing.filechooser.*;

/**
 * Classe filtrant les dossiers du choix 
 * de fichier d'un JFileChooser
 * @version 1.14
 * @since 5/11/05
 * @author Olivio_Mariano
 * @see FileFilter
 */
 
public class FiltreFichier extends FileFilter {

    private static String TYPE_UNKNOWN = "Type Inconnu";
    private static String HIDDEN_FILE = "Fichier cach";

    private Hashtable filters = null;
    private String description = null;
    private String fullDescription = null;
    private boolean useExtensionsInDescription = true;

    /**
    * Cree un filtre fichier. Si le filtre n'est 
    * pas ajoute, alors tous les types de fichiers
    * seront accepts.
    *
    * @see #addExtension
    */
    public FiltreFichier() {
   this.filters = new Hashtable();
    }

    /**
     * Cree un filtre fichier qui accepte des fichiers avec une extension predefinie. 
     * Example: new ExampleFileFilter("jpg");
     *
     * @see #addExtension
     */
    public FiltreFichier(String extension) {
   this(extension,null);
    }

    /**
     * Cree un filtre fichier qui accepte le type de fichier donnee.
     * Example: new ExampleFileFilter("jpg", "JPEG Image Images");
     *
     * @see #addExtension
     */
    public FiltreFichier(String extension, String description) {
   this();
   if(extension!=null) addExtension(extension);
    if(description!=null) setDescription(description);
    }

    /**
     * Cree un filtre fichier a partir de la chaine de characteres
     * Example: new ExampleFileFilter(String {"gif", "jpg"});
     *
     * @see #addExtension
     */
    public FiltreFichier(String[] filters) {
   this(filters, null);
    }

    /**
     * Cree un filtre fichier a partir de la chaine de characteres et de la desciption
     * Example: new ExampleFileFilter(String {"gif", "jpg"}, "Gif and JPG Images");
     *
     * @see #addExtension
     */
    public FiltreFichier(String[] filters, String description) {
   this();
   for (int i = 0; i < filters.length; i++) {
       // add filters one by one
       addExtension(filters[i]);
   }
    if(description!=null) setDescription(description);
    }

    /**
     * Retourne vrai si le fichier doit etre affiche dans le paneau,
     * faux sinon
     * 
     * Les fichier avec "." seront ignores.
     *
     * @see #getExtension
     * @return boolean
     */
    public boolean accept(File f) {
   if(f != null) {
       if(f.isDirectory()) {
      return true;
       }
       String extension = getExtension(f);
       if(extension != null && filters.get(getExtension(f)) != null) {
      return true;
       };
   }
   return false;
    }

    /**
     * Retourne la portion "extension" du fichier .
     *
     * @see #getExtension
     * @see FileFilter#accept
     */
     public String getExtension(File f) {
   if(f != null) {
       String filename = f.getName();
       int i = filename.lastIndexOf('.');
       if(i>0 && i<filename.length()-1) {
      return filename.substring(i+1).toLowerCase();
       };
   }
   return null;
    }

    /**
     * Ajoute un type de fichier avec l'extension "." pour effectuer un filtre
     * Adds a filetype "dot" extension to filter against.
     *
     *   ExampleFileFilter filter = new ExampleFileFilter();
     *   filter.addExtension("mp3");
     *   filter.addExtension("avi");
     */
    public void addExtension(String extension) {
   if(filters == null) {
       filters = new Hashtable(5);
   }
   filters.put(extension.toLowerCase(), this);
   fullDescription = null;
    }


    /**
     * Renvoie une description lisible du filtre. Par
     * exemple: "Fichiers MPEG et mp3  (*.mpg, *.mp3)"
     *
     */
    public String getDescription() {
   if(fullDescription == null) {
       if(description == null || isExtensionListInDescription()) {
       fullDescription = description==null ? "(" : description + " (";
      // build the description from the extension list
      Enumeration extensions = filters.keys();
      if(extensions != null) {
          fullDescription += "." + (String) extensions.nextElement();
          while (extensions.hasMoreElements()) {
         fullDescription += ", ." + (String) extensions.nextElement();
          }
      }
      fullDescription += ")";
       } else {
      fullDescription = description;
       }
   }
   return fullDescription;
    }

    /**
     * Affiche la description lisible du filtre. Par
     * exemple: filter.setDescription("Fichiers MPEG et mp3");
     */
    public void setDescription(String description) {
   this.description = description;
   fullDescription = null;
    }

    /**
     * Dtermine la liste des extensions (.mpg, .mp3, etc)
     */
    public void setExtensionListInDescription(boolean b) {
   useExtensionsInDescription = b;
   fullDescription = null;
    }

    /**
     * Renvoie la liste des extensions (.jpg, .gif, etc) 
     *
     */
    public boolean isExtensionListInDescription() {
   return useExtensionsInDescription;
    }
}